@@ -190,11 +190,16 @@ class MimePart(object):
     @property
     def size(self):
         """ Returns message size in bytes"""
-        if isinstance(self._container, Stream):
-            return self._container.size
+        if self.is_root() and not self.was_changed():
+            if isinstance(self._container, Stream):
+                return self._container.size
+            else:
+                return sum(part._container.size
+                           for part in self.walk(with_self=True))
         else:
-            return sum(part._container.size
-                       for part in self.walk(with_self=True))
+            with closing(_CounterIO()) as out:
+                self.to_stream(out)
+                return out.getvalue()
 
     @property
     def headers(self):
@@ -358,6 +363,7 @@ class MimePart(object):
                 out.seek(original_position)
                 out.write(self._container.read_message())
 
+
     def to_stream_when_changed(self, out):
 
         ctype = self.content_type
@@ -607,3 +613,17 @@ def has_long_lines(text, max_line_len=599):
     return False
 
 CRLF = "\r\n"
+
+class _CounterIO(object):
+    def __init__(self):
+        self.length = 0
+    def tell(self):
+        return self.length
+    def write(self, s):
+        self.length += len(s)
+    def seek(self, p):
+        self.length = p
+    def getvalue(self):
+        return self.length
+    def close(self):
+        pass
