@@ -1,6 +1,8 @@
 # coding:utf-8
 import re
 
+from functools import wraps
+
 '''
 Utility functions and classes used by flanker.
 '''
@@ -55,6 +57,28 @@ def contains_control_chars(s):
     return False
 
 
+def metrics_wrapper():
+
+    def decorate(f):
+        @wraps(f)
+        def wrapper(*args, **kwargs):
+            return_value = f(*args, **kwargs)
+            if 'metrics' in kwargs and kwargs['metrics'] == True:
+                #return all values
+                return return_value
+
+            # if we have a single item
+            if len(return_value[:-1]) == 1:
+                return return_value[0]
+
+            # return all except the last value
+            return return_value[:-1]
+
+        return wrapper
+
+    return decorate
+
+
 # allows, \t\n\v\f\r (0x09-0x0d)
 CONTROL_CHARS = ''.join(map(unichr, range(0, 9) + range(14, 32) + range(127, 160)))
 CONTROL_CHAR_RE = re.compile('[%s]' % re.escape(CONTROL_CHARS))
